@@ -23,14 +23,11 @@ class JWTAuthMiddleware(MiddlewareMixin):
             return
 
         token = auth_header[7:]
-        request.realm = auth_header
         try:
             info = verifier.verify_token(token)
         except ExpiredSignatureError:
-            return JsonResponse(
-                status=HTTPStatus.UNAUTHORIZED.value, data={"error": "expired token"}
-            )
+            return JsonResponse(status=HTTPStatus.UNAUTHORIZED.value, data={"detail": "expired token"})
         except Exception as exc:
             log.error("Unexpected error", exc)
             return
-        request.user = request._cached_user = UserHandler(info).get_user()
+        request.user = request._cached_user = UserHandler(info, request).get_user()
